@@ -36,7 +36,7 @@ e - beastmode unleashed
 
 =cut
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 =head1 SYNOPSIS
 
@@ -297,6 +297,18 @@ sub import {
             Mojo::URL->new( @_ );
         },
 
+        ######################################
+        #              Pod
+        ######################################
+
+        pod => sub {
+            require App::Pod;
+            App::Pod->import;
+
+            local @ARGV = @_;
+            App::Pod->run;
+        },
+
         ######################################
         #         Package Building
         ######################################
